asn1_* renamed into asn_*


git-svn-id: https://asn1c.svn.sourceforge.net/svnroot/asn1c/trunk@446 59561ff5-6e30-0410-9f3c-9617f08c8826
diff --git a/skeletons/constr_SEQUENCE.h b/skeletons/constr_SEQUENCE.h
index 27903b1..0b36079 100644
--- a/skeletons/constr_SEQUENCE.h
+++ b/skeletons/constr_SEQUENCE.h
@@ -7,17 +7,17 @@
 
 #include <asn_application.h>
 
-typedef struct asn1_SEQUENCE_specifics_s {
+typedef struct asn_SEQUENCE_specifics_s {
 	/*
 	 * Target structure description.
 	 */
 	int struct_size;	/* Size of the target structure. */
-	int ctx_offset;		/* Offset of the ber_dec_ctx_t member */
+	int ctx_offset;		/* Offset of the asn_struct_ctx_t member */
 
 	/*
 	 * Tags to members mapping table (sorted).
 	 */
-	asn1_TYPE_tag2member_t *tag2el;
+	asn_TYPE_tag2member_t *tag2el;
 	int tag2el_count;
 
 	/*
@@ -25,7 +25,7 @@
 	 */
 	int ext_after;	/* Extensions start after this member */
 	int ext_before;	/* Extensions stop before this member */
-} asn1_SEQUENCE_specifics_t;
+} asn_SEQUENCE_specifics_t;
 
 
 /*